# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class WebhookResultDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'webhook_id': 'str',
        'webhook_url': 'str',
        'message_id': 'str',
        'redrive_id': 'str',
        'http_method': 'str',
        'webhook_event': 'str',
        'response_status': 'int',
        'response_time_millis': 'int',
        'response_body_extract': 'str',
        'result_type': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'seen': 'bool',
        'inbox_id': 'str',
        'email_id': 'str',
        'attachment_id': 'str',
        'phone_id': 'str',
        'sms_id': 'str',
        'ai_transformer_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'webhook_id': 'webhookId',
        'webhook_url': 'webhookUrl',
        'message_id': 'messageId',
        'redrive_id': 'redriveId',
        'http_method': 'httpMethod',
        'webhook_event': 'webhookEvent',
        'response_status': 'responseStatus',
        'response_time_millis': 'responseTimeMillis',
        'response_body_extract': 'responseBodyExtract',
        'result_type': 'resultType',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'seen': 'seen',
        'inbox_id': 'inboxId',
        'email_id': 'emailId',
        'attachment_id': 'attachmentId',
        'phone_id': 'phoneId',
        'sms_id': 'smsId',
        'ai_transformer_id': 'aiTransformerId'
    }

    def __init__(self, id=None, user_id=None, webhook_id=None, webhook_url=None, message_id=None, redrive_id=None, http_method=None, webhook_event=None, response_status=None, response_time_millis=None, response_body_extract=None, result_type=None, created_at=None, updated_at=None, seen=None, inbox_id=None, email_id=None, attachment_id=None, phone_id=None, sms_id=None, ai_transformer_id=None, local_vars_configuration=None):  # noqa: E501
        """WebhookResultDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._webhook_id = None
        self._webhook_url = None
        self._message_id = None
        self._redrive_id = None
        self._http_method = None
        self._webhook_event = None
        self._response_status = None
        self._response_time_millis = None
        self._response_body_extract = None
        self._result_type = None
        self._created_at = None
        self._updated_at = None
        self._seen = None
        self._inbox_id = None
        self._email_id = None
        self._attachment_id = None
        self._phone_id = None
        self._sms_id = None
        self._ai_transformer_id = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.webhook_id = webhook_id
        self.webhook_url = webhook_url
        self.message_id = message_id
        self.redrive_id = redrive_id
        self.http_method = http_method
        self.webhook_event = webhook_event
        self.response_status = response_status
        self.response_time_millis = response_time_millis
        self.response_body_extract = response_body_extract
        self.result_type = result_type
        self.created_at = created_at
        self.updated_at = updated_at
        self.seen = seen
        self.inbox_id = inbox_id
        self.email_id = email_id
        self.attachment_id = attachment_id
        self.phone_id = phone_id
        self.sms_id = sms_id
        self.ai_transformer_id = ai_transformer_id

    @property
    def id(self):
        """Gets the id of this WebhookResultDto.  # noqa: E501


        :return: The id of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WebhookResultDto.


        :param id: The id of this WebhookResultDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this WebhookResultDto.  # noqa: E501


        :return: The user_id of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this WebhookResultDto.


        :param user_id: The user_id of this WebhookResultDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def webhook_id(self):
        """Gets the webhook_id of this WebhookResultDto.  # noqa: E501


        :return: The webhook_id of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._webhook_id

    @webhook_id.setter
    def webhook_id(self, webhook_id):
        """Sets the webhook_id of this WebhookResultDto.


        :param webhook_id: The webhook_id of this WebhookResultDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and webhook_id is None:  # noqa: E501
            raise ValueError("Invalid value for `webhook_id`, must not be `None`")  # noqa: E501

        self._webhook_id = webhook_id

    @property
    def webhook_url(self):
        """Gets the webhook_url of this WebhookResultDto.  # noqa: E501


        :return: The webhook_url of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._webhook_url

    @webhook_url.setter
    def webhook_url(self, webhook_url):
        """Sets the webhook_url of this WebhookResultDto.


        :param webhook_url: The webhook_url of this WebhookResultDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and webhook_url is None:  # noqa: E501
            raise ValueError("Invalid value for `webhook_url`, must not be `None`")  # noqa: E501

        self._webhook_url = webhook_url

    @property
    def message_id(self):
        """Gets the message_id of this WebhookResultDto.  # noqa: E501


        :return: The message_id of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this WebhookResultDto.


        :param message_id: The message_id of this WebhookResultDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and message_id is None:  # noqa: E501
            raise ValueError("Invalid value for `message_id`, must not be `None`")  # noqa: E501

        self._message_id = message_id

    @property
    def redrive_id(self):
        """Gets the redrive_id of this WebhookResultDto.  # noqa: E501


        :return: The redrive_id of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._redrive_id

    @redrive_id.setter
    def redrive_id(self, redrive_id):
        """Sets the redrive_id of this WebhookResultDto.


        :param redrive_id: The redrive_id of this WebhookResultDto.  # noqa: E501
        :type: str
        """

        self._redrive_id = redrive_id

    @property
    def http_method(self):
        """Gets the http_method of this WebhookResultDto.  # noqa: E501


        :return: The http_method of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._http_method

    @http_method.setter
    def http_method(self, http_method):
        """Sets the http_method of this WebhookResultDto.


        :param http_method: The http_method of this WebhookResultDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and http_method is None:  # noqa: E501
            raise ValueError("Invalid value for `http_method`, must not be `None`")  # noqa: E501
        allowed_values = ["POST", "DELETE", "GET", "PUT", "PATCH", "HEAD", "OPTIONS", "TRACE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and http_method not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `http_method` ({0}), must be one of {1}"  # noqa: E501
                .format(http_method, allowed_values)
            )

        self._http_method = http_method

    @property
    def webhook_event(self):
        """Gets the webhook_event of this WebhookResultDto.  # noqa: E501


        :return: The webhook_event of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._webhook_event

    @webhook_event.setter
    def webhook_event(self, webhook_event):
        """Sets the webhook_event of this WebhookResultDto.


        :param webhook_event: The webhook_event of this WebhookResultDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and webhook_event is None:  # noqa: E501
            raise ValueError("Invalid value for `webhook_event`, must not be `None`")  # noqa: E501
        allowed_values = ["EMAIL_RECEIVED", "NEW_AI_TRANSFORM_RESULT", "NEW_EMAIL", "NEW_CONTACT", "NEW_ATTACHMENT", "EMAIL_OPENED", "EMAIL_READ", "DELIVERY_STATUS", "BOUNCE", "BOUNCE_RECIPIENT", "NEW_SMS", "NEW_GUEST_USER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and webhook_event not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `webhook_event` ({0}), must be one of {1}"  # noqa: E501
                .format(webhook_event, allowed_values)
            )

        self._webhook_event = webhook_event

    @property
    def response_status(self):
        """Gets the response_status of this WebhookResultDto.  # noqa: E501


        :return: The response_status of this WebhookResultDto.  # noqa: E501
        :rtype: int
        """
        return self._response_status

    @response_status.setter
    def response_status(self, response_status):
        """Sets the response_status of this WebhookResultDto.


        :param response_status: The response_status of this WebhookResultDto.  # noqa: E501
        :type: int
        """

        self._response_status = response_status

    @property
    def response_time_millis(self):
        """Gets the response_time_millis of this WebhookResultDto.  # noqa: E501


        :return: The response_time_millis of this WebhookResultDto.  # noqa: E501
        :rtype: int
        """
        return self._response_time_millis

    @response_time_millis.setter
    def response_time_millis(self, response_time_millis):
        """Sets the response_time_millis of this WebhookResultDto.


        :param response_time_millis: The response_time_millis of this WebhookResultDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and response_time_millis is None:  # noqa: E501
            raise ValueError("Invalid value for `response_time_millis`, must not be `None`")  # noqa: E501

        self._response_time_millis = response_time_millis

    @property
    def response_body_extract(self):
        """Gets the response_body_extract of this WebhookResultDto.  # noqa: E501


        :return: The response_body_extract of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._response_body_extract

    @response_body_extract.setter
    def response_body_extract(self, response_body_extract):
        """Sets the response_body_extract of this WebhookResultDto.


        :param response_body_extract: The response_body_extract of this WebhookResultDto.  # noqa: E501
        :type: str
        """

        self._response_body_extract = response_body_extract

    @property
    def result_type(self):
        """Gets the result_type of this WebhookResultDto.  # noqa: E501


        :return: The result_type of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._result_type

    @result_type.setter
    def result_type(self, result_type):
        """Sets the result_type of this WebhookResultDto.


        :param result_type: The result_type of this WebhookResultDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"BAD_RESPONSE", "EXCEPTION", "SUCCESS", "REDRIVEN"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and result_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `result_type` ({0}), must be one of {1}"  # noqa: E501
                .format(result_type, allowed_values)
            )

        self._result_type = result_type

    @property
    def created_at(self):
        """Gets the created_at of this WebhookResultDto.  # noqa: E501


        :return: The created_at of this WebhookResultDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this WebhookResultDto.


        :param created_at: The created_at of this WebhookResultDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this WebhookResultDto.  # noqa: E501


        :return: The updated_at of this WebhookResultDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this WebhookResultDto.


        :param updated_at: The updated_at of this WebhookResultDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def seen(self):
        """Gets the seen of this WebhookResultDto.  # noqa: E501


        :return: The seen of this WebhookResultDto.  # noqa: E501
        :rtype: bool
        """
        return self._seen

    @seen.setter
    def seen(self, seen):
        """Sets the seen of this WebhookResultDto.


        :param seen: The seen of this WebhookResultDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and seen is None:  # noqa: E501
            raise ValueError("Invalid value for `seen`, must not be `None`")  # noqa: E501

        self._seen = seen

    @property
    def inbox_id(self):
        """Gets the inbox_id of this WebhookResultDto.  # noqa: E501


        :return: The inbox_id of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this WebhookResultDto.


        :param inbox_id: The inbox_id of this WebhookResultDto.  # noqa: E501
        :type: str
        """

        self._inbox_id = inbox_id

    @property
    def email_id(self):
        """Gets the email_id of this WebhookResultDto.  # noqa: E501


        :return: The email_id of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this WebhookResultDto.


        :param email_id: The email_id of this WebhookResultDto.  # noqa: E501
        :type: str
        """

        self._email_id = email_id

    @property
    def attachment_id(self):
        """Gets the attachment_id of this WebhookResultDto.  # noqa: E501


        :return: The attachment_id of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._attachment_id

    @attachment_id.setter
    def attachment_id(self, attachment_id):
        """Sets the attachment_id of this WebhookResultDto.


        :param attachment_id: The attachment_id of this WebhookResultDto.  # noqa: E501
        :type: str
        """

        self._attachment_id = attachment_id

    @property
    def phone_id(self):
        """Gets the phone_id of this WebhookResultDto.  # noqa: E501


        :return: The phone_id of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_id

    @phone_id.setter
    def phone_id(self, phone_id):
        """Sets the phone_id of this WebhookResultDto.


        :param phone_id: The phone_id of this WebhookResultDto.  # noqa: E501
        :type: str
        """

        self._phone_id = phone_id

    @property
    def sms_id(self):
        """Gets the sms_id of this WebhookResultDto.  # noqa: E501


        :return: The sms_id of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._sms_id

    @sms_id.setter
    def sms_id(self, sms_id):
        """Sets the sms_id of this WebhookResultDto.


        :param sms_id: The sms_id of this WebhookResultDto.  # noqa: E501
        :type: str
        """

        self._sms_id = sms_id

    @property
    def ai_transformer_id(self):
        """Gets the ai_transformer_id of this WebhookResultDto.  # noqa: E501


        :return: The ai_transformer_id of this WebhookResultDto.  # noqa: E501
        :rtype: str
        """
        return self._ai_transformer_id

    @ai_transformer_id.setter
    def ai_transformer_id(self, ai_transformer_id):
        """Sets the ai_transformer_id of this WebhookResultDto.


        :param ai_transformer_id: The ai_transformer_id of this WebhookResultDto.  # noqa: E501
        :type: str
        """

        self._ai_transformer_id = ai_transformer_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookResultDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebhookResultDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class GenerateStructuredContentAttachmentOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'attachment_id': 'str',
        'instructions': 'str',
        'output_schema': 'StructuredOutputSchema',
        'transform_id': 'str',
        'email_id': 'str'
    }

    attribute_map = {
        'attachment_id': 'attachmentId',
        'instructions': 'instructions',
        'output_schema': 'outputSchema',
        'transform_id': 'transformId',
        'email_id': 'emailId'
    }

    def __init__(self, attachment_id=None, instructions=None, output_schema=None, transform_id=None, email_id=None, local_vars_configuration=None):  # noqa: E501
        """GenerateStructuredContentAttachmentOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._attachment_id = None
        self._instructions = None
        self._output_schema = None
        self._transform_id = None
        self._email_id = None
        self.discriminator = None

        self.attachment_id = attachment_id
        self.instructions = instructions
        self.output_schema = output_schema
        self.transform_id = transform_id
        self.email_id = email_id

    @property
    def attachment_id(self):
        """Gets the attachment_id of this GenerateStructuredContentAttachmentOptions.  # noqa: E501

        Attachment ID to read and pass to AI  # noqa: E501

        :return: The attachment_id of this GenerateStructuredContentAttachmentOptions.  # noqa: E501
        :rtype: str
        """
        return self._attachment_id

    @attachment_id.setter
    def attachment_id(self, attachment_id):
        """Sets the attachment_id of this GenerateStructuredContentAttachmentOptions.

        Attachment ID to read and pass to AI  # noqa: E501

        :param attachment_id: The attachment_id of this GenerateStructuredContentAttachmentOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and attachment_id is None:  # noqa: E501
            raise ValueError("Invalid value for `attachment_id`, must not be `None`")  # noqa: E501

        self._attachment_id = attachment_id

    @property
    def instructions(self):
        """Gets the instructions of this GenerateStructuredContentAttachmentOptions.  # noqa: E501

        Optional instructions for the AI to follow. Try to be precise and clear. You can include examples and hints.  # noqa: E501

        :return: The instructions of this GenerateStructuredContentAttachmentOptions.  # noqa: E501
        :rtype: str
        """
        return self._instructions

    @instructions.setter
    def instructions(self, instructions):
        """Sets the instructions of this GenerateStructuredContentAttachmentOptions.

        Optional instructions for the AI to follow. Try to be precise and clear. You can include examples and hints.  # noqa: E501

        :param instructions: The instructions of this GenerateStructuredContentAttachmentOptions.  # noqa: E501
        :type: str
        """

        self._instructions = instructions

    @property
    def output_schema(self):
        """Gets the output_schema of this GenerateStructuredContentAttachmentOptions.  # noqa: E501


        :return: The output_schema of this GenerateStructuredContentAttachmentOptions.  # noqa: E501
        :rtype: StructuredOutputSchema
        """
        return self._output_schema

    @output_schema.setter
    def output_schema(self, output_schema):
        """Sets the output_schema of this GenerateStructuredContentAttachmentOptions.


        :param output_schema: The output_schema of this GenerateStructuredContentAttachmentOptions.  # noqa: E501
        :type: StructuredOutputSchema
        """

        self._output_schema = output_schema

    @property
    def transform_id(self):
        """Gets the transform_id of this GenerateStructuredContentAttachmentOptions.  # noqa: E501

        ID of transformer to apply  # noqa: E501

        :return: The transform_id of this GenerateStructuredContentAttachmentOptions.  # noqa: E501
        :rtype: str
        """
        return self._transform_id

    @transform_id.setter
    def transform_id(self, transform_id):
        """Sets the transform_id of this GenerateStructuredContentAttachmentOptions.

        ID of transformer to apply  # noqa: E501

        :param transform_id: The transform_id of this GenerateStructuredContentAttachmentOptions.  # noqa: E501
        :type: str
        """

        self._transform_id = transform_id

    @property
    def email_id(self):
        """Gets the email_id of this GenerateStructuredContentAttachmentOptions.  # noqa: E501

        Optional email ID for more context  # noqa: E501

        :return: The email_id of this GenerateStructuredContentAttachmentOptions.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this GenerateStructuredContentAttachmentOptions.

        Optional email ID for more context  # noqa: E501

        :param email_id: The email_id of this GenerateStructuredContentAttachmentOptions.  # noqa: E501
        :type: str
        """

        self._email_id = email_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerateStructuredContentAttachmentOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GenerateStructuredContentAttachmentOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DomainMonitorRunComparisonDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'baseline': 'DomainMonitorRunDto',
        'current': 'DomainMonitorRunDto',
        'health_score_delta': 'int',
        'status_changed': 'bool',
        'passing_checks_delta': 'int',
        'failing_checks_delta': 'int',
        'spf_changed': 'bool',
        'dmarc_changed': 'bool',
        'dmarc_enforced_changed': 'bool',
        'mx_changed': 'bool',
        'added_insights': 'list[str]',
        'removed_insights': 'list[str]'
    }

    attribute_map = {
        'baseline': 'baseline',
        'current': 'current',
        'health_score_delta': 'healthScoreDelta',
        'status_changed': 'statusChanged',
        'passing_checks_delta': 'passingChecksDelta',
        'failing_checks_delta': 'failingChecksDelta',
        'spf_changed': 'spfChanged',
        'dmarc_changed': 'dmarcChanged',
        'dmarc_enforced_changed': 'dmarcEnforcedChanged',
        'mx_changed': 'mxChanged',
        'added_insights': 'addedInsights',
        'removed_insights': 'removedInsights'
    }

    def __init__(self, baseline=None, current=None, health_score_delta=None, status_changed=None, passing_checks_delta=None, failing_checks_delta=None, spf_changed=None, dmarc_changed=None, dmarc_enforced_changed=None, mx_changed=None, added_insights=None, removed_insights=None, local_vars_configuration=None):  # noqa: E501
        """DomainMonitorRunComparisonDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._baseline = None
        self._current = None
        self._health_score_delta = None
        self._status_changed = None
        self._passing_checks_delta = None
        self._failing_checks_delta = None
        self._spf_changed = None
        self._dmarc_changed = None
        self._dmarc_enforced_changed = None
        self._mx_changed = None
        self._added_insights = None
        self._removed_insights = None
        self.discriminator = None

        self.baseline = baseline
        self.current = current
        self.health_score_delta = health_score_delta
        self.status_changed = status_changed
        self.passing_checks_delta = passing_checks_delta
        self.failing_checks_delta = failing_checks_delta
        self.spf_changed = spf_changed
        self.dmarc_changed = dmarc_changed
        self.dmarc_enforced_changed = dmarc_enforced_changed
        self.mx_changed = mx_changed
        self.added_insights = added_insights
        self.removed_insights = removed_insights

    @property
    def baseline(self):
        """Gets the baseline of this DomainMonitorRunComparisonDto.  # noqa: E501


        :return: The baseline of this DomainMonitorRunComparisonDto.  # noqa: E501
        :rtype: DomainMonitorRunDto
        """
        return self._baseline

    @baseline.setter
    def baseline(self, baseline):
        """Sets the baseline of this DomainMonitorRunComparisonDto.


        :param baseline: The baseline of this DomainMonitorRunComparisonDto.  # noqa: E501
        :type: DomainMonitorRunDto
        """
        if self.local_vars_configuration.client_side_validation and baseline is None:  # noqa: E501
            raise ValueError("Invalid value for `baseline`, must not be `None`")  # noqa: E501

        self._baseline = baseline

    @property
    def current(self):
        """Gets the current of this DomainMonitorRunComparisonDto.  # noqa: E501


        :return: The current of this DomainMonitorRunComparisonDto.  # noqa: E501
        :rtype: DomainMonitorRunDto
        """
        return self._current

    @current.setter
    def current(self, current):
        """Sets the current of this DomainMonitorRunComparisonDto.


        :param current: The current of this DomainMonitorRunComparisonDto.  # noqa: E501
        :type: DomainMonitorRunDto
        """
        if self.local_vars_configuration.client_side_validation and current is None:  # noqa: E501
            raise ValueError("Invalid value for `current`, must not be `None`")  # noqa: E501

        self._current = current

    @property
    def health_score_delta(self):
        """Gets the health_score_delta of this DomainMonitorRunComparisonDto.  # noqa: E501


        :return: The health_score_delta of this DomainMonitorRunComparisonDto.  # noqa: E501
        :rtype: int
        """
        return self._health_score_delta

    @health_score_delta.setter
    def health_score_delta(self, health_score_delta):
        """Sets the health_score_delta of this DomainMonitorRunComparisonDto.


        :param health_score_delta: The health_score_delta of this DomainMonitorRunComparisonDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and health_score_delta is None:  # noqa: E501
            raise ValueError("Invalid value for `health_score_delta`, must not be `None`")  # noqa: E501

        self._health_score_delta = health_score_delta

    @property
    def status_changed(self):
        """Gets the status_changed of this DomainMonitorRunComparisonDto.  # noqa: E501


        :return: The status_changed of this DomainMonitorRunComparisonDto.  # noqa: E501
        :rtype: bool
        """
        return self._status_changed

    @status_changed.setter
    def status_changed(self, status_changed):
        """Sets the status_changed of this DomainMonitorRunComparisonDto.


        :param status_changed: The status_changed of this DomainMonitorRunComparisonDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and status_changed is None:  # noqa: E501
            raise ValueError("Invalid value for `status_changed`, must not be `None`")  # noqa: E501

        self._status_changed = status_changed

    @property
    def passing_checks_delta(self):
        """Gets the passing_checks_delta of this DomainMonitorRunComparisonDto.  # noqa: E501


        :return: The passing_checks_delta of this DomainMonitorRunComparisonDto.  # noqa: E501
        :rtype: int
        """
        return self._passing_checks_delta

    @passing_checks_delta.setter
    def passing_checks_delta(self, passing_checks_delta):
        """Sets the passing_checks_delta of this DomainMonitorRunComparisonDto.


        :param passing_checks_delta: The passing_checks_delta of this DomainMonitorRunComparisonDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and passing_checks_delta is None:  # noqa: E501
            raise ValueError("Invalid value for `passing_checks_delta`, must not be `None`")  # noqa: E501

        self._passing_checks_delta = passing_checks_delta

    @property
    def failing_checks_delta(self):
        """Gets the failing_checks_delta of this DomainMonitorRunComparisonDto.  # noqa: E501


        :return: The failing_checks_delta of this DomainMonitorRunComparisonDto.  # noqa: E501
        :rtype: int
        """
        return self._failing_checks_delta

    @failing_checks_delta.setter
    def failing_checks_delta(self, failing_checks_delta):
        """Sets the failing_checks_delta of this DomainMonitorRunComparisonDto.


        :param failing_checks_delta: The failing_checks_delta of this DomainMonitorRunComparisonDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failing_checks_delta is None:  # noqa: E501
            raise ValueError("Invalid value for `failing_checks_delta`, must not be `None`")  # noqa: E501

        self._failing_checks_delta = failing_checks_delta

    @property
    def spf_changed(self):
        """Gets the spf_changed of this DomainMonitorRunComparisonDto.  # noqa: E501


        :return: The spf_changed of this DomainMonitorRunComparisonDto.  # noqa: E501
        :rtype: bool
        """
        return self._spf_changed

    @spf_changed.setter
    def spf_changed(self, spf_changed):
        """Sets the spf_changed of this DomainMonitorRunComparisonDto.


        :param spf_changed: The spf_changed of this DomainMonitorRunComparisonDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and spf_changed is None:  # noqa: E501
            raise ValueError("Invalid value for `spf_changed`, must not be `None`")  # noqa: E501

        self._spf_changed = spf_changed

    @property
    def dmarc_changed(self):
        """Gets the dmarc_changed of this DomainMonitorRunComparisonDto.  # noqa: E501


        :return: The dmarc_changed of this DomainMonitorRunComparisonDto.  # noqa: E501
        :rtype: bool
        """
        return self._dmarc_changed

    @dmarc_changed.setter
    def dmarc_changed(self, dmarc_changed):
        """Sets the dmarc_changed of this DomainMonitorRunComparisonDto.


        :param dmarc_changed: The dmarc_changed of this DomainMonitorRunComparisonDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and dmarc_changed is None:  # noqa: E501
            raise ValueError("Invalid value for `dmarc_changed`, must not be `None`")  # noqa: E501

        self._dmarc_changed = dmarc_changed

    @property
    def dmarc_enforced_changed(self):
        """Gets the dmarc_enforced_changed of this DomainMonitorRunComparisonDto.  # noqa: E501


        :return: The dmarc_enforced_changed of this DomainMonitorRunComparisonDto.  # noqa: E501
        :rtype: bool
        """
        return self._dmarc_enforced_changed

    @dmarc_enforced_changed.setter
    def dmarc_enforced_changed(self, dmarc_enforced_changed):
        """Sets the dmarc_enforced_changed of this DomainMonitorRunComparisonDto.


        :param dmarc_enforced_changed: The dmarc_enforced_changed of this DomainMonitorRunComparisonDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and dmarc_enforced_changed is None:  # noqa: E501
            raise ValueError("Invalid value for `dmarc_enforced_changed`, must not be `None`")  # noqa: E501

        self._dmarc_enforced_changed = dmarc_enforced_changed

    @property
    def mx_changed(self):
        """Gets the mx_changed of this DomainMonitorRunComparisonDto.  # noqa: E501


        :return: The mx_changed of this DomainMonitorRunComparisonDto.  # noqa: E501
        :rtype: bool
        """
        return self._mx_changed

    @mx_changed.setter
    def mx_changed(self, mx_changed):
        """Sets the mx_changed of this DomainMonitorRunComparisonDto.


        :param mx_changed: The mx_changed of this DomainMonitorRunComparisonDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and mx_changed is None:  # noqa: E501
            raise ValueError("Invalid value for `mx_changed`, must not be `None`")  # noqa: E501

        self._mx_changed = mx_changed

    @property
    def added_insights(self):
        """Gets the added_insights of this DomainMonitorRunComparisonDto.  # noqa: E501


        :return: The added_insights of this DomainMonitorRunComparisonDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._added_insights

    @added_insights.setter
    def added_insights(self, added_insights):
        """Sets the added_insights of this DomainMonitorRunComparisonDto.


        :param added_insights: The added_insights of this DomainMonitorRunComparisonDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and added_insights is None:  # noqa: E501
            raise ValueError("Invalid value for `added_insights`, must not be `None`")  # noqa: E501

        self._added_insights = added_insights

    @property
    def removed_insights(self):
        """Gets the removed_insights of this DomainMonitorRunComparisonDto.  # noqa: E501


        :return: The removed_insights of this DomainMonitorRunComparisonDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._removed_insights

    @removed_insights.setter
    def removed_insights(self, removed_insights):
        """Sets the removed_insights of this DomainMonitorRunComparisonDto.


        :param removed_insights: The removed_insights of this DomainMonitorRunComparisonDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and removed_insights is None:  # noqa: E501
            raise ValueError("Invalid value for `removed_insights`, must not be `None`")  # noqa: E501

        self._removed_insights = removed_insights

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DomainMonitorRunComparisonDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DomainMonitorRunComparisonDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mailslurp_client
from mailslurp_client.models.check_email_auth_stack_results import CheckEmailAuthStackResults  # noqa: E501
from mailslurp_client.rest import ApiException

class TestCheckEmailAuthStackResults(unittest.TestCase):
    """CheckEmailAuthStackResults unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CheckEmailAuthStackResults
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mailslurp_client.models.check_email_auth_stack_results.CheckEmailAuthStackResults()  # noqa: E501
        if include_optional :
            return CheckEmailAuthStackResults(
                domain = '0', 
                status = 'HEALTHY', 
                health_score = 56, 
                total_checks = 56, 
                passing_checks = 56, 
                failing_checks = 56, 
                spf = mailslurp_client.models.lookup_spf_domain_results.LookupSpfDomainResults(
                    valid = True, 
                    host = '0', 
                    record = '0', 
                    flattened_record = '0', 
                    lookup_count = 56, 
                    mechanisms = [
                        mailslurp_client.models.spf_mechanism_result.SpfMechanismResult(
                            kind = '0', 
                            value = '0', 
                            qualifier = '0', )
                        ], 
                    warnings = [
                        '0'
                        ], 
                    errors = [
                        '0'
                        ], ), 
                dmarc = mailslurp_client.models.lookup_dmarc_domain_results.LookupDmarcDomainResults(
                    valid = True, 
                    query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                        hostname = '0', 
                        record_types = [
                            'A'
                            ], 
                        omit_final_dns_dot = True, ), 
                    records = [
                        mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                            record_type = 'A', 
                            ttl = 56, 
                            record_entries = [
                                '0'
                                ], 
                            name = '0', )
                        ], 
                    errors = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], ), 
                dkim = mailslurp_client.models.lookup_dkim_domain_results.LookupDkimDomainResults(
                    valid = True, 
                    queried_name = '0', 
                    selector = '0', 
                    record = '0', 
                    algorithm = '0', 
                    key_length = 56, 
                    checked_names = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], 
                    errors = [
                        '0'
                        ], ), 
                bimi = mailslurp_client.models.lookup_bimi_domain_results.LookupBimiDomainResults(
                    valid = True, 
                    query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                        hostname = '0', 
                        record_types = [
                            'A'
                            ], 
                        omit_final_dns_dot = True, ), 
                    records = [
                        mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                            record_type = 'A', 
                            ttl = 56, 
                            record_entries = [
                                '0'
                                ], 
                            name = '0', )
                        ], 
                    errors = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], ), 
                mx = mailslurp_client.models.lookup_mx_records_results.LookupMxRecordsResults(
                    records = [
                        mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                            record_type = 'A', 
                            ttl = 56, 
                            record_entries = [
                                '0'
                                ], 
                            name = '0', )
                        ], 
                    errors = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], ), 
                mta_sts = mailslurp_client.models.lookup_mta_sts_domain_results.LookupMtaStsDomainResults(
                    valid = True, 
                    query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                        hostname = '0', 
                        record_types = [
                            'A'
                            ], 
                        omit_final_dns_dot = True, ), 
                    records = [
                        mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                            record_type = 'A', 
                            ttl = 56, 
                            record_entries = [
                                '0'
                                ], 
                            name = '0', )
                        ], 
                    well_known_query = '0', 
                    well_known_present = True, 
                    well_known_value = '0', 
                    errors = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], ), 
                tls_reporting = mailslurp_client.models.lookup_tls_reporting_domain_results.LookupTlsReportingDomainResults(
                    valid = True, 
                    query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                        hostname = '0', 
                        record_types = [
                            'A'
                            ], 
                        omit_final_dns_dot = True, ), 
                    records = [
                        mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                            record_type = 'A', 
                            ttl = 56, 
                            record_entries = [
                                '0'
                                ], 
                            name = '0', )
                        ], 
                    errors = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], ), 
                insights = [
                    '0'
                    ], 
                warnings = [
                    '0'
                    ], 
                errors = [
                    '0'
                    ]
            )
        else :
            return CheckEmailAuthStackResults(
                domain = '0',
                status = 'HEALTHY',
                health_score = 56,
                total_checks = 56,
                passing_checks = 56,
                failing_checks = 56,
                spf = mailslurp_client.models.lookup_spf_domain_results.LookupSpfDomainResults(
                    valid = True, 
                    host = '0', 
                    record = '0', 
                    flattened_record = '0', 
                    lookup_count = 56, 
                    mechanisms = [
                        mailslurp_client.models.spf_mechanism_result.SpfMechanismResult(
                            kind = '0', 
                            value = '0', 
                            qualifier = '0', )
                        ], 
                    warnings = [
                        '0'
                        ], 
                    errors = [
                        '0'
                        ], ),
                dmarc = mailslurp_client.models.lookup_dmarc_domain_results.LookupDmarcDomainResults(
                    valid = True, 
                    query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                        hostname = '0', 
                        record_types = [
                            'A'
                            ], 
                        omit_final_dns_dot = True, ), 
                    records = [
                        mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                            record_type = 'A', 
                            ttl = 56, 
                            record_entries = [
                                '0'
                                ], 
                            name = '0', )
                        ], 
                    errors = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], ),
                dkim = mailslurp_client.models.lookup_dkim_domain_results.LookupDkimDomainResults(
                    valid = True, 
                    queried_name = '0', 
                    selector = '0', 
                    record = '0', 
                    algorithm = '0', 
                    key_length = 56, 
                    checked_names = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], 
                    errors = [
                        '0'
                        ], ),
                bimi = mailslurp_client.models.lookup_bimi_domain_results.LookupBimiDomainResults(
                    valid = True, 
                    query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                        hostname = '0', 
                        record_types = [
                            'A'
                            ], 
                        omit_final_dns_dot = True, ), 
                    records = [
                        mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                            record_type = 'A', 
                            ttl = 56, 
                            record_entries = [
                                '0'
                                ], 
                            name = '0', )
                        ], 
                    errors = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], ),
                mx = mailslurp_client.models.lookup_mx_records_results.LookupMxRecordsResults(
                    records = [
                        mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                            record_type = 'A', 
                            ttl = 56, 
                            record_entries = [
                                '0'
                                ], 
                            name = '0', )
                        ], 
                    errors = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], ),
                mta_sts = mailslurp_client.models.lookup_mta_sts_domain_results.LookupMtaStsDomainResults(
                    valid = True, 
                    query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                        hostname = '0', 
                        record_types = [
                            'A'
                            ], 
                        omit_final_dns_dot = True, ), 
                    records = [
                        mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                            record_type = 'A', 
                            ttl = 56, 
                            record_entries = [
                                '0'
                                ], 
                            name = '0', )
                        ], 
                    well_known_query = '0', 
                    well_known_present = True, 
                    well_known_value = '0', 
                    errors = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], ),
                tls_reporting = mailslurp_client.models.lookup_tls_reporting_domain_results.LookupTlsReportingDomainResults(
                    valid = True, 
                    query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                        hostname = '0', 
                        record_types = [
                            'A'
                            ], 
                        omit_final_dns_dot = True, ), 
                    records = [
                        mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                            record_type = 'A', 
                            ttl = 56, 
                            record_entries = [
                                '0'
                                ], 
                            name = '0', )
                        ], 
                    errors = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], ),
                insights = [
                    '0'
                    ],
                warnings = [
                    '0'
                    ],
                errors = [
                    '0'
                    ],
        )

    def testCheckEmailAuthStackResults(self):
        """Test CheckEmailAuthStackResults"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class BouncedEmailDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'notification_type': 'str',
        'sent_to_recipients': 'list[str]',
        'sender': 'str',
        'bounce_mta': 'str',
        'bounce_type': 'str',
        'bounce_recipients': 'list[str]',
        'bounce_sub_type': 'str',
        'sent_email_id': 'str',
        'subject': 'str',
        'created_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'notification_type': 'notificationType',
        'sent_to_recipients': 'sentToRecipients',
        'sender': 'sender',
        'bounce_mta': 'bounceMta',
        'bounce_type': 'bounceType',
        'bounce_recipients': 'bounceRecipients',
        'bounce_sub_type': 'bounceSubType',
        'sent_email_id': 'sentEmailId',
        'subject': 'subject',
        'created_at': 'createdAt'
    }

    def __init__(self, id=None, user_id=None, notification_type=None, sent_to_recipients=None, sender=None, bounce_mta=None, bounce_type=None, bounce_recipients=None, bounce_sub_type=None, sent_email_id=None, subject=None, created_at=None, local_vars_configuration=None):  # noqa: E501
        """BouncedEmailDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._notification_type = None
        self._sent_to_recipients = None
        self._sender = None
        self._bounce_mta = None
        self._bounce_type = None
        self._bounce_recipients = None
        self._bounce_sub_type = None
        self._sent_email_id = None
        self._subject = None
        self._created_at = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.notification_type = notification_type
        self.sent_to_recipients = sent_to_recipients
        self.sender = sender
        self.bounce_mta = bounce_mta
        self.bounce_type = bounce_type
        self.bounce_recipients = bounce_recipients
        self.bounce_sub_type = bounce_sub_type
        self.sent_email_id = sent_email_id
        self.subject = subject
        self.created_at = created_at

    @property
    def id(self):
        """Gets the id of this BouncedEmailDto.  # noqa: E501


        :return: The id of this BouncedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BouncedEmailDto.


        :param id: The id of this BouncedEmailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this BouncedEmailDto.  # noqa: E501


        :return: The user_id of this BouncedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this BouncedEmailDto.


        :param user_id: The user_id of this BouncedEmailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def notification_type(self):
        """Gets the notification_type of this BouncedEmailDto.  # noqa: E501


        :return: The notification_type of this BouncedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._notification_type

    @notification_type.setter
    def notification_type(self, notification_type):
        """Sets the notification_type of this BouncedEmailDto.


        :param notification_type: The notification_type of this BouncedEmailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and notification_type is None:  # noqa: E501
            raise ValueError("Invalid value for `notification_type`, must not be `None`")  # noqa: E501

        self._notification_type = notification_type

    @property
    def sent_to_recipients(self):
        """Gets the sent_to_recipients of this BouncedEmailDto.  # noqa: E501


        :return: The sent_to_recipients of this BouncedEmailDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._sent_to_recipients

    @sent_to_recipients.setter
    def sent_to_recipients(self, sent_to_recipients):
        """Sets the sent_to_recipients of this BouncedEmailDto.


        :param sent_to_recipients: The sent_to_recipients of this BouncedEmailDto.  # noqa: E501
        :type: list[str]
        """

        self._sent_to_recipients = sent_to_recipients

    @property
    def sender(self):
        """Gets the sender of this BouncedEmailDto.  # noqa: E501


        :return: The sender of this BouncedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._sender

    @sender.setter
    def sender(self, sender):
        """Sets the sender of this BouncedEmailDto.


        :param sender: The sender of this BouncedEmailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and sender is None:  # noqa: E501
            raise ValueError("Invalid value for `sender`, must not be `None`")  # noqa: E501

        self._sender = sender

    @property
    def bounce_mta(self):
        """Gets the bounce_mta of this BouncedEmailDto.  # noqa: E501


        :return: The bounce_mta of this BouncedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._bounce_mta

    @bounce_mta.setter
    def bounce_mta(self, bounce_mta):
        """Sets the bounce_mta of this BouncedEmailDto.


        :param bounce_mta: The bounce_mta of this BouncedEmailDto.  # noqa: E501
        :type: str
        """

        self._bounce_mta = bounce_mta

    @property
    def bounce_type(self):
        """Gets the bounce_type of this BouncedEmailDto.  # noqa: E501


        :return: The bounce_type of this BouncedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._bounce_type

    @bounce_type.setter
    def bounce_type(self, bounce_type):
        """Sets the bounce_type of this BouncedEmailDto.


        :param bounce_type: The bounce_type of this BouncedEmailDto.  # noqa: E501
        :type: str
        """

        self._bounce_type = bounce_type

    @property
    def bounce_recipients(self):
        """Gets the bounce_recipients of this BouncedEmailDto.  # noqa: E501


        :return: The bounce_recipients of this BouncedEmailDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._bounce_recipients

    @bounce_recipients.setter
    def bounce_recipients(self, bounce_recipients):
        """Sets the bounce_recipients of this BouncedEmailDto.


        :param bounce_recipients: The bounce_recipients of this BouncedEmailDto.  # noqa: E501
        :type: list[str]
        """

        self._bounce_recipients = bounce_recipients

    @property
    def bounce_sub_type(self):
        """Gets the bounce_sub_type of this BouncedEmailDto.  # noqa: E501


        :return: The bounce_sub_type of this BouncedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._bounce_sub_type

    @bounce_sub_type.setter
    def bounce_sub_type(self, bounce_sub_type):
        """Sets the bounce_sub_type of this BouncedEmailDto.


        :param bounce_sub_type: The bounce_sub_type of this BouncedEmailDto.  # noqa: E501
        :type: str
        """

        self._bounce_sub_type = bounce_sub_type

    @property
    def sent_email_id(self):
        """Gets the sent_email_id of this BouncedEmailDto.  # noqa: E501


        :return: The sent_email_id of this BouncedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._sent_email_id

    @sent_email_id.setter
    def sent_email_id(self, sent_email_id):
        """Sets the sent_email_id of this BouncedEmailDto.


        :param sent_email_id: The sent_email_id of this BouncedEmailDto.  # noqa: E501
        :type: str
        """

        self._sent_email_id = sent_email_id

    @property
    def subject(self):
        """Gets the subject of this BouncedEmailDto.  # noqa: E501


        :return: The subject of this BouncedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this BouncedEmailDto.


        :param subject: The subject of this BouncedEmailDto.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def created_at(self):
        """Gets the created_at of this BouncedEmailDto.  # noqa: E501


        :return: The created_at of this BouncedEmailDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BouncedEmailDto.


        :param created_at: The created_at of this BouncedEmailDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BouncedEmailDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BouncedEmailDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreatePortalUserOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'password': 'str',
        'name': 'str',
        'username': 'str',
        'skip_inbox_creation': 'bool',
        'inbox_id': 'str',
        'create_inbox_options': 'CreateInboxDto'
    }

    attribute_map = {
        'password': 'password',
        'name': 'name',
        'username': 'username',
        'skip_inbox_creation': 'skipInboxCreation',
        'inbox_id': 'inboxId',
        'create_inbox_options': 'createInboxOptions'
    }

    def __init__(self, password=None, name=None, username=None, skip_inbox_creation=None, inbox_id=None, create_inbox_options=None, local_vars_configuration=None):  # noqa: E501
        """CreatePortalUserOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._password = None
        self._name = None
        self._username = None
        self._skip_inbox_creation = None
        self._inbox_id = None
        self._create_inbox_options = None
        self.discriminator = None

        if password is not None:
            self.password = password
        if name is not None:
            self.name = name
        if username is not None:
            self.username = username
        if skip_inbox_creation is not None:
            self.skip_inbox_creation = skip_inbox_creation
        if inbox_id is not None:
            self.inbox_id = inbox_id
        if create_inbox_options is not None:
            self.create_inbox_options = create_inbox_options

    @property
    def password(self):
        """Gets the password of this CreatePortalUserOptions.  # noqa: E501


        :return: The password of this CreatePortalUserOptions.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this CreatePortalUserOptions.


        :param password: The password of this CreatePortalUserOptions.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def name(self):
        """Gets the name of this CreatePortalUserOptions.  # noqa: E501


        :return: The name of this CreatePortalUserOptions.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreatePortalUserOptions.


        :param name: The name of this CreatePortalUserOptions.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def username(self):
        """Gets the username of this CreatePortalUserOptions.  # noqa: E501


        :return: The username of this CreatePortalUserOptions.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this CreatePortalUserOptions.


        :param username: The username of this CreatePortalUserOptions.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def skip_inbox_creation(self):
        """Gets the skip_inbox_creation of this CreatePortalUserOptions.  # noqa: E501


        :return: The skip_inbox_creation of this CreatePortalUserOptions.  # noqa: E501
        :rtype: bool
        """
        return self._skip_inbox_creation

    @skip_inbox_creation.setter
    def skip_inbox_creation(self, skip_inbox_creation):
        """Sets the skip_inbox_creation of this CreatePortalUserOptions.


        :param skip_inbox_creation: The skip_inbox_creation of this CreatePortalUserOptions.  # noqa: E501
        :type: bool
        """

        self._skip_inbox_creation = skip_inbox_creation

    @property
    def inbox_id(self):
        """Gets the inbox_id of this CreatePortalUserOptions.  # noqa: E501


        :return: The inbox_id of this CreatePortalUserOptions.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this CreatePortalUserOptions.


        :param inbox_id: The inbox_id of this CreatePortalUserOptions.  # noqa: E501
        :type: str
        """

        self._inbox_id = inbox_id

    @property
    def create_inbox_options(self):
        """Gets the create_inbox_options of this CreatePortalUserOptions.  # noqa: E501


        :return: The create_inbox_options of this CreatePortalUserOptions.  # noqa: E501
        :rtype: CreateInboxDto
        """
        return self._create_inbox_options

    @create_inbox_options.setter
    def create_inbox_options(self, create_inbox_options):
        """Sets the create_inbox_options of this CreatePortalUserOptions.


        :param create_inbox_options: The create_inbox_options of this CreatePortalUserOptions.  # noqa: E501
        :type: CreateInboxDto
        """

        self._create_inbox_options = create_inbox_options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreatePortalUserOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreatePortalUserOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AnalyzeDmarcReportResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'metadata': 'DmarcReportMetadata',
        'record_count': 'int',
        'total_messages': 'int',
        'reject_count': 'int',
        'quarantine_count': 'int',
        'none_count': 'int',
        'dkim_aligned_count': 'int',
        'spf_aligned_count': 'int',
        'fully_aligned_count': 'int',
        'failed_alignment_count': 'int',
        'top_sources': 'list[DmarcReportSourceSummary]',
        'warnings': 'list[str]',
        'errors': 'list[str]'
    }

    attribute_map = {
        'metadata': 'metadata',
        'record_count': 'recordCount',
        'total_messages': 'totalMessages',
        'reject_count': 'rejectCount',
        'quarantine_count': 'quarantineCount',
        'none_count': 'noneCount',
        'dkim_aligned_count': 'dkimAlignedCount',
        'spf_aligned_count': 'spfAlignedCount',
        'fully_aligned_count': 'fullyAlignedCount',
        'failed_alignment_count': 'failedAlignmentCount',
        'top_sources': 'topSources',
        'warnings': 'warnings',
        'errors': 'errors'
    }

    def __init__(self, metadata=None, record_count=None, total_messages=None, reject_count=None, quarantine_count=None, none_count=None, dkim_aligned_count=None, spf_aligned_count=None, fully_aligned_count=None, failed_alignment_count=None, top_sources=None, warnings=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """AnalyzeDmarcReportResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._metadata = None
        self._record_count = None
        self._total_messages = None
        self._reject_count = None
        self._quarantine_count = None
        self._none_count = None
        self._dkim_aligned_count = None
        self._spf_aligned_count = None
        self._fully_aligned_count = None
        self._failed_alignment_count = None
        self._top_sources = None
        self._warnings = None
        self._errors = None
        self.discriminator = None

        self.metadata = metadata
        self.record_count = record_count
        self.total_messages = total_messages
        self.reject_count = reject_count
        self.quarantine_count = quarantine_count
        self.none_count = none_count
        self.dkim_aligned_count = dkim_aligned_count
        self.spf_aligned_count = spf_aligned_count
        self.fully_aligned_count = fully_aligned_count
        self.failed_alignment_count = failed_alignment_count
        self.top_sources = top_sources
        self.warnings = warnings
        self.errors = errors

    @property
    def metadata(self):
        """Gets the metadata of this AnalyzeDmarcReportResults.  # noqa: E501


        :return: The metadata of this AnalyzeDmarcReportResults.  # noqa: E501
        :rtype: DmarcReportMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this AnalyzeDmarcReportResults.


        :param metadata: The metadata of this AnalyzeDmarcReportResults.  # noqa: E501
        :type: DmarcReportMetadata
        """
        if self.local_vars_configuration.client_side_validation and metadata is None:  # noqa: E501
            raise ValueError("Invalid value for `metadata`, must not be `None`")  # noqa: E501

        self._metadata = metadata

    @property
    def record_count(self):
        """Gets the record_count of this AnalyzeDmarcReportResults.  # noqa: E501


        :return: The record_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :rtype: int
        """
        return self._record_count

    @record_count.setter
    def record_count(self, record_count):
        """Sets the record_count of this AnalyzeDmarcReportResults.


        :param record_count: The record_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and record_count is None:  # noqa: E501
            raise ValueError("Invalid value for `record_count`, must not be `None`")  # noqa: E501

        self._record_count = record_count

    @property
    def total_messages(self):
        """Gets the total_messages of this AnalyzeDmarcReportResults.  # noqa: E501


        :return: The total_messages of this AnalyzeDmarcReportResults.  # noqa: E501
        :rtype: int
        """
        return self._total_messages

    @total_messages.setter
    def total_messages(self, total_messages):
        """Sets the total_messages of this AnalyzeDmarcReportResults.


        :param total_messages: The total_messages of this AnalyzeDmarcReportResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_messages is None:  # noqa: E501
            raise ValueError("Invalid value for `total_messages`, must not be `None`")  # noqa: E501

        self._total_messages = total_messages

    @property
    def reject_count(self):
        """Gets the reject_count of this AnalyzeDmarcReportResults.  # noqa: E501


        :return: The reject_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :rtype: int
        """
        return self._reject_count

    @reject_count.setter
    def reject_count(self, reject_count):
        """Sets the reject_count of this AnalyzeDmarcReportResults.


        :param reject_count: The reject_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and reject_count is None:  # noqa: E501
            raise ValueError("Invalid value for `reject_count`, must not be `None`")  # noqa: E501

        self._reject_count = reject_count

    @property
    def quarantine_count(self):
        """Gets the quarantine_count of this AnalyzeDmarcReportResults.  # noqa: E501


        :return: The quarantine_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :rtype: int
        """
        return self._quarantine_count

    @quarantine_count.setter
    def quarantine_count(self, quarantine_count):
        """Sets the quarantine_count of this AnalyzeDmarcReportResults.


        :param quarantine_count: The quarantine_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and quarantine_count is None:  # noqa: E501
            raise ValueError("Invalid value for `quarantine_count`, must not be `None`")  # noqa: E501

        self._quarantine_count = quarantine_count

    @property
    def none_count(self):
        """Gets the none_count of this AnalyzeDmarcReportResults.  # noqa: E501


        :return: The none_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :rtype: int
        """
        return self._none_count

    @none_count.setter
    def none_count(self, none_count):
        """Sets the none_count of this AnalyzeDmarcReportResults.


        :param none_count: The none_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and none_count is None:  # noqa: E501
            raise ValueError("Invalid value for `none_count`, must not be `None`")  # noqa: E501

        self._none_count = none_count

    @property
    def dkim_aligned_count(self):
        """Gets the dkim_aligned_count of this AnalyzeDmarcReportResults.  # noqa: E501


        :return: The dkim_aligned_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :rtype: int
        """
        return self._dkim_aligned_count

    @dkim_aligned_count.setter
    def dkim_aligned_count(self, dkim_aligned_count):
        """Sets the dkim_aligned_count of this AnalyzeDmarcReportResults.


        :param dkim_aligned_count: The dkim_aligned_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and dkim_aligned_count is None:  # noqa: E501
            raise ValueError("Invalid value for `dkim_aligned_count`, must not be `None`")  # noqa: E501

        self._dkim_aligned_count = dkim_aligned_count

    @property
    def spf_aligned_count(self):
        """Gets the spf_aligned_count of this AnalyzeDmarcReportResults.  # noqa: E501


        :return: The spf_aligned_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :rtype: int
        """
        return self._spf_aligned_count

    @spf_aligned_count.setter
    def spf_aligned_count(self, spf_aligned_count):
        """Sets the spf_aligned_count of this AnalyzeDmarcReportResults.


        :param spf_aligned_count: The spf_aligned_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and spf_aligned_count is None:  # noqa: E501
            raise ValueError("Invalid value for `spf_aligned_count`, must not be `None`")  # noqa: E501

        self._spf_aligned_count = spf_aligned_count

    @property
    def fully_aligned_count(self):
        """Gets the fully_aligned_count of this AnalyzeDmarcReportResults.  # noqa: E501


        :return: The fully_aligned_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :rtype: int
        """
        return self._fully_aligned_count

    @fully_aligned_count.setter
    def fully_aligned_count(self, fully_aligned_count):
        """Sets the fully_aligned_count of this AnalyzeDmarcReportResults.


        :param fully_aligned_count: The fully_aligned_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and fully_aligned_count is None:  # noqa: E501
            raise ValueError("Invalid value for `fully_aligned_count`, must not be `None`")  # noqa: E501

        self._fully_aligned_count = fully_aligned_count

    @property
    def failed_alignment_count(self):
        """Gets the failed_alignment_count of this AnalyzeDmarcReportResults.  # noqa: E501


        :return: The failed_alignment_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :rtype: int
        """
        return self._failed_alignment_count

    @failed_alignment_count.setter
    def failed_alignment_count(self, failed_alignment_count):
        """Sets the failed_alignment_count of this AnalyzeDmarcReportResults.


        :param failed_alignment_count: The failed_alignment_count of this AnalyzeDmarcReportResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_alignment_count is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_alignment_count`, must not be `None`")  # noqa: E501

        self._failed_alignment_count = failed_alignment_count

    @property
    def top_sources(self):
        """Gets the top_sources of this AnalyzeDmarcReportResults.  # noqa: E501


        :return: The top_sources of this AnalyzeDmarcReportResults.  # noqa: E501
        :rtype: list[DmarcReportSourceSummary]
        """
        return self._top_sources

    @top_sources.setter
    def top_sources(self, top_sources):
        """Sets the top_sources of this AnalyzeDmarcReportResults.


        :param top_sources: The top_sources of this AnalyzeDmarcReportResults.  # noqa: E501
        :type: list[DmarcReportSourceSummary]
        """
        if self.local_vars_configuration.client_side_validation and top_sources is None:  # noqa: E501
            raise ValueError("Invalid value for `top_sources`, must not be `None`")  # noqa: E501

        self._top_sources = top_sources

    @property
    def warnings(self):
        """Gets the warnings of this AnalyzeDmarcReportResults.  # noqa: E501


        :return: The warnings of this AnalyzeDmarcReportResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this AnalyzeDmarcReportResults.


        :param warnings: The warnings of this AnalyzeDmarcReportResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    @property
    def errors(self):
        """Gets the errors of this AnalyzeDmarcReportResults.  # noqa: E501


        :return: The errors of this AnalyzeDmarcReportResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this AnalyzeDmarcReportResults.


        :param errors: The errors of this AnalyzeDmarcReportResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyzeDmarcReportResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AnalyzeDmarcReportResults):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class InvokeTransformerOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ai_transform_id': 'str',
        'ai_transform_mapping_id': 'str',
        'raw_input': 'str',
        'entity_id': 'str',
        'entity_type': 'str',
        'raw_conditions': 'list[str]',
        'raw_instructions': 'list[str]',
        'raw_output_schema': 'StructuredOutputSchema',
        'content_selector': 'str',
        'save_results': 'bool'
    }

    attribute_map = {
        'ai_transform_id': 'aiTransformId',
        'ai_transform_mapping_id': 'aiTransformMappingId',
        'raw_input': 'rawInput',
        'entity_id': 'entityId',
        'entity_type': 'entityType',
        'raw_conditions': 'rawConditions',
        'raw_instructions': 'rawInstructions',
        'raw_output_schema': 'rawOutputSchema',
        'content_selector': 'contentSelector',
        'save_results': 'saveResults'
    }

    def __init__(self, ai_transform_id=None, ai_transform_mapping_id=None, raw_input=None, entity_id=None, entity_type=None, raw_conditions=None, raw_instructions=None, raw_output_schema=None, content_selector=None, save_results=None, local_vars_configuration=None):  # noqa: E501
        """InvokeTransformerOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ai_transform_id = None
        self._ai_transform_mapping_id = None
        self._raw_input = None
        self._entity_id = None
        self._entity_type = None
        self._raw_conditions = None
        self._raw_instructions = None
        self._raw_output_schema = None
        self._content_selector = None
        self._save_results = None
        self.discriminator = None

        self.ai_transform_id = ai_transform_id
        self.ai_transform_mapping_id = ai_transform_mapping_id
        self.raw_input = raw_input
        self.entity_id = entity_id
        self.entity_type = entity_type
        self.raw_conditions = raw_conditions
        self.raw_instructions = raw_instructions
        self.raw_output_schema = raw_output_schema
        self.content_selector = content_selector
        self.save_results = save_results

    @property
    def ai_transform_id(self):
        """Gets the ai_transform_id of this InvokeTransformerOptions.  # noqa: E501


        :return: The ai_transform_id of this InvokeTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_id

    @ai_transform_id.setter
    def ai_transform_id(self, ai_transform_id):
        """Sets the ai_transform_id of this InvokeTransformerOptions.


        :param ai_transform_id: The ai_transform_id of this InvokeTransformerOptions.  # noqa: E501
        :type: str
        """

        self._ai_transform_id = ai_transform_id

    @property
    def ai_transform_mapping_id(self):
        """Gets the ai_transform_mapping_id of this InvokeTransformerOptions.  # noqa: E501


        :return: The ai_transform_mapping_id of this InvokeTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_mapping_id

    @ai_transform_mapping_id.setter
    def ai_transform_mapping_id(self, ai_transform_mapping_id):
        """Sets the ai_transform_mapping_id of this InvokeTransformerOptions.


        :param ai_transform_mapping_id: The ai_transform_mapping_id of this InvokeTransformerOptions.  # noqa: E501
        :type: str
        """

        self._ai_transform_mapping_id = ai_transform_mapping_id

    @property
    def raw_input(self):
        """Gets the raw_input of this InvokeTransformerOptions.  # noqa: E501


        :return: The raw_input of this InvokeTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._raw_input

    @raw_input.setter
    def raw_input(self, raw_input):
        """Sets the raw_input of this InvokeTransformerOptions.


        :param raw_input: The raw_input of this InvokeTransformerOptions.  # noqa: E501
        :type: str
        """

        self._raw_input = raw_input

    @property
    def entity_id(self):
        """Gets the entity_id of this InvokeTransformerOptions.  # noqa: E501


        :return: The entity_id of this InvokeTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this InvokeTransformerOptions.


        :param entity_id: The entity_id of this InvokeTransformerOptions.  # noqa: E501
        :type: str
        """

        self._entity_id = entity_id

    @property
    def entity_type(self):
        """Gets the entity_type of this InvokeTransformerOptions.  # noqa: E501


        :return: The entity_type of this InvokeTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this InvokeTransformerOptions.


        :param entity_type: The entity_type of this InvokeTransformerOptions.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"EMAIL", "SMS", "ATTACHMENT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and entity_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `entity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(entity_type, allowed_values)
            )

        self._entity_type = entity_type

    @property
    def raw_conditions(self):
        """Gets the raw_conditions of this InvokeTransformerOptions.  # noqa: E501


        :return: The raw_conditions of this InvokeTransformerOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._raw_conditions

    @raw_conditions.setter
    def raw_conditions(self, raw_conditions):
        """Sets the raw_conditions of this InvokeTransformerOptions.


        :param raw_conditions: The raw_conditions of this InvokeTransformerOptions.  # noqa: E501
        :type: list[str]
        """

        self._raw_conditions = raw_conditions

    @property
    def raw_instructions(self):
        """Gets the raw_instructions of this InvokeTransformerOptions.  # noqa: E501


        :return: The raw_instructions of this InvokeTransformerOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._raw_instructions

    @raw_instructions.setter
    def raw_instructions(self, raw_instructions):
        """Sets the raw_instructions of this InvokeTransformerOptions.


        :param raw_instructions: The raw_instructions of this InvokeTransformerOptions.  # noqa: E501
        :type: list[str]
        """

        self._raw_instructions = raw_instructions

    @property
    def raw_output_schema(self):
        """Gets the raw_output_schema of this InvokeTransformerOptions.  # noqa: E501


        :return: The raw_output_schema of this InvokeTransformerOptions.  # noqa: E501
        :rtype: StructuredOutputSchema
        """
        return self._raw_output_schema

    @raw_output_schema.setter
    def raw_output_schema(self, raw_output_schema):
        """Sets the raw_output_schema of this InvokeTransformerOptions.


        :param raw_output_schema: The raw_output_schema of this InvokeTransformerOptions.  # noqa: E501
        :type: StructuredOutputSchema
        """

        self._raw_output_schema = raw_output_schema

    @property
    def content_selector(self):
        """Gets the content_selector of this InvokeTransformerOptions.  # noqa: E501


        :return: The content_selector of this InvokeTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._content_selector

    @content_selector.setter
    def content_selector(self, content_selector):
        """Sets the content_selector of this InvokeTransformerOptions.


        :param content_selector: The content_selector of this InvokeTransformerOptions.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"RAW", "BODY", "BODY_ATTACHMENTS"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and content_selector not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `content_selector` ({0}), must be one of {1}"  # noqa: E501
                .format(content_selector, allowed_values)
            )

        self._content_selector = content_selector

    @property
    def save_results(self):
        """Gets the save_results of this InvokeTransformerOptions.  # noqa: E501


        :return: The save_results of this InvokeTransformerOptions.  # noqa: E501
        :rtype: bool
        """
        return self._save_results

    @save_results.setter
    def save_results(self, save_results):
        """Sets the save_results of this InvokeTransformerOptions.


        :param save_results: The save_results of this InvokeTransformerOptions.  # noqa: E501
        :type: bool
        """

        self._save_results = save_results

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvokeTransformerOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InvokeTransformerOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class TenantReputationFindingDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_region': 'str',
        'tenant_name': 'str',
        'tenant_arn': 'str',
        'type': 'str',
        'impact': 'str',
        'status': 'str',
        'description': 'str',
        'created_timestamp': 'datetime',
        'last_updated_timestamp': 'datetime'
    }

    attribute_map = {
        'account_region': 'accountRegion',
        'tenant_name': 'tenantName',
        'tenant_arn': 'tenantArn',
        'type': 'type',
        'impact': 'impact',
        'status': 'status',
        'description': 'description',
        'created_timestamp': 'createdTimestamp',
        'last_updated_timestamp': 'lastUpdatedTimestamp'
    }

    def __init__(self, account_region=None, tenant_name=None, tenant_arn=None, type=None, impact=None, status=None, description=None, created_timestamp=None, last_updated_timestamp=None, local_vars_configuration=None):  # noqa: E501
        """TenantReputationFindingDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_region = None
        self._tenant_name = None
        self._tenant_arn = None
        self._type = None
        self._impact = None
        self._status = None
        self._description = None
        self._created_timestamp = None
        self._last_updated_timestamp = None
        self.discriminator = None

        self.account_region = account_region
        self.tenant_name = tenant_name
        if tenant_arn is not None:
            self.tenant_arn = tenant_arn
        if type is not None:
            self.type = type
        if impact is not None:
            self.impact = impact
        if status is not None:
            self.status = status
        if description is not None:
            self.description = description
        if created_timestamp is not None:
            self.created_timestamp = created_timestamp
        if last_updated_timestamp is not None:
            self.last_updated_timestamp = last_updated_timestamp

    @property
    def account_region(self):
        """Gets the account_region of this TenantReputationFindingDto.  # noqa: E501


        :return: The account_region of this TenantReputationFindingDto.  # noqa: E501
        :rtype: str
        """
        return self._account_region

    @account_region.setter
    def account_region(self, account_region):
        """Sets the account_region of this TenantReputationFindingDto.


        :param account_region: The account_region of this TenantReputationFindingDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and account_region is None:  # noqa: E501
            raise ValueError("Invalid value for `account_region`, must not be `None`")  # noqa: E501
        allowed_values = ["US_WEST_2_ACCOUNT_STAGING", "US_EAST_1_ACCOUNT_STAGING", "EU_WEST_1_ACCOUNT_STAGING", "US_WEST_2_ACCOUNT_SES_1", "EU_WEST_1_ACCOUNT_SES_1", "US_WEST_2_ACCOUNT_SES_2", "EU_WEST_1_ACCOUNT_SES_2", "US_WEST_2_ACCOUNT_BYTEWISE", "EU_WEST_1_ACCOUNT_BYTEWISE", "US_WEST_2", "EU_WEST_1", "US_EAST_1"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and account_region not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `account_region` ({0}), must be one of {1}"  # noqa: E501
                .format(account_region, allowed_values)
            )

        self._account_region = account_region

    @property
    def tenant_name(self):
        """Gets the tenant_name of this TenantReputationFindingDto.  # noqa: E501


        :return: The tenant_name of this TenantReputationFindingDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_name

    @tenant_name.setter
    def tenant_name(self, tenant_name):
        """Sets the tenant_name of this TenantReputationFindingDto.


        :param tenant_name: The tenant_name of this TenantReputationFindingDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and tenant_name is None:  # noqa: E501
            raise ValueError("Invalid value for `tenant_name`, must not be `None`")  # noqa: E501

        self._tenant_name = tenant_name

    @property
    def tenant_arn(self):
        """Gets the tenant_arn of this TenantReputationFindingDto.  # noqa: E501


        :return: The tenant_arn of this TenantReputationFindingDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_arn

    @tenant_arn.setter
    def tenant_arn(self, tenant_arn):
        """Sets the tenant_arn of this TenantReputationFindingDto.


        :param tenant_arn: The tenant_arn of this TenantReputationFindingDto.  # noqa: E501
        :type: str
        """

        self._tenant_arn = tenant_arn

    @property
    def type(self):
        """Gets the type of this TenantReputationFindingDto.  # noqa: E501


        :return: The type of this TenantReputationFindingDto.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this TenantReputationFindingDto.


        :param type: The type of this TenantReputationFindingDto.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def impact(self):
        """Gets the impact of this TenantReputationFindingDto.  # noqa: E501


        :return: The impact of this TenantReputationFindingDto.  # noqa: E501
        :rtype: str
        """
        return self._impact

    @impact.setter
    def impact(self, impact):
        """Sets the impact of this TenantReputationFindingDto.


        :param impact: The impact of this TenantReputationFindingDto.  # noqa: E501
        :type: str
        """

        self._impact = impact

    @property
    def status(self):
        """Gets the status of this TenantReputationFindingDto.  # noqa: E501


        :return: The status of this TenantReputationFindingDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this TenantReputationFindingDto.


        :param status: The status of this TenantReputationFindingDto.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def description(self):
        """Gets the description of this TenantReputationFindingDto.  # noqa: E501


        :return: The description of this TenantReputationFindingDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TenantReputationFindingDto.


        :param description: The description of this TenantReputationFindingDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def created_timestamp(self):
        """Gets the created_timestamp of this TenantReputationFindingDto.  # noqa: E501


        :return: The created_timestamp of this TenantReputationFindingDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_timestamp

    @created_timestamp.setter
    def created_timestamp(self, created_timestamp):
        """Sets the created_timestamp of this TenantReputationFindingDto.


        :param created_timestamp: The created_timestamp of this TenantReputationFindingDto.  # noqa: E501
        :type: datetime
        """

        self._created_timestamp = created_timestamp

    @property
    def last_updated_timestamp(self):
        """Gets the last_updated_timestamp of this TenantReputationFindingDto.  # noqa: E501


        :return: The last_updated_timestamp of this TenantReputationFindingDto.  # noqa: E501
        :rtype: datetime
        """
        return self._last_updated_timestamp

    @last_updated_timestamp.setter
    def last_updated_timestamp(self, last_updated_timestamp):
        """Sets the last_updated_timestamp of this TenantReputationFindingDto.


        :param last_updated_timestamp: The last_updated_timestamp of this TenantReputationFindingDto.  # noqa: E501
        :type: datetime
        """

        self._last_updated_timestamp = last_updated_timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TenantReputationFindingDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TenantReputationFindingDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class Complaint(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'event_type': 'str',
        'mail_source': 'str',
        'mail_message_id': 'str',
        'complaint_recipient': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'event_type': 'eventType',
        'mail_source': 'mailSource',
        'mail_message_id': 'mailMessageId',
        'complaint_recipient': 'complaintRecipient',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, user_id=None, event_type=None, mail_source=None, mail_message_id=None, complaint_recipient=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """Complaint - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._event_type = None
        self._mail_source = None
        self._mail_message_id = None
        self._complaint_recipient = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        if user_id is not None:
            self.user_id = user_id
        if event_type is not None:
            self.event_type = event_type
        if mail_source is not None:
            self.mail_source = mail_source
        if mail_message_id is not None:
            self.mail_message_id = mail_message_id
        self.complaint_recipient = complaint_recipient
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this Complaint.  # noqa: E501


        :return: The id of this Complaint.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Complaint.


        :param id: The id of this Complaint.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this Complaint.  # noqa: E501


        :return: The user_id of this Complaint.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this Complaint.


        :param user_id: The user_id of this Complaint.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def event_type(self):
        """Gets the event_type of this Complaint.  # noqa: E501


        :return: The event_type of this Complaint.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this Complaint.


        :param event_type: The event_type of this Complaint.  # noqa: E501
        :type: str
        """

        self._event_type = event_type

    @property
    def mail_source(self):
        """Gets the mail_source of this Complaint.  # noqa: E501


        :return: The mail_source of this Complaint.  # noqa: E501
        :rtype: str
        """
        return self._mail_source

    @mail_source.setter
    def mail_source(self, mail_source):
        """Sets the mail_source of this Complaint.


        :param mail_source: The mail_source of this Complaint.  # noqa: E501
        :type: str
        """

        self._mail_source = mail_source

    @property
    def mail_message_id(self):
        """Gets the mail_message_id of this Complaint.  # noqa: E501


        :return: The mail_message_id of this Complaint.  # noqa: E501
        :rtype: str
        """
        return self._mail_message_id

    @mail_message_id.setter
    def mail_message_id(self, mail_message_id):
        """Sets the mail_message_id of this Complaint.


        :param mail_message_id: The mail_message_id of this Complaint.  # noqa: E501
        :type: str
        """

        self._mail_message_id = mail_message_id

    @property
    def complaint_recipient(self):
        """Gets the complaint_recipient of this Complaint.  # noqa: E501


        :return: The complaint_recipient of this Complaint.  # noqa: E501
        :rtype: str
        """
        return self._complaint_recipient

    @complaint_recipient.setter
    def complaint_recipient(self, complaint_recipient):
        """Sets the complaint_recipient of this Complaint.


        :param complaint_recipient: The complaint_recipient of this Complaint.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and complaint_recipient is None:  # noqa: E501
            raise ValueError("Invalid value for `complaint_recipient`, must not be `None`")  # noqa: E501

        self._complaint_recipient = complaint_recipient

    @property
    def created_at(self):
        """Gets the created_at of this Complaint.  # noqa: E501


        :return: The created_at of this Complaint.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Complaint.


        :param created_at: The created_at of this Complaint.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Complaint.  # noqa: E501


        :return: The updated_at of this Complaint.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Complaint.


        :param updated_at: The updated_at of this Complaint.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Complaint):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Complaint):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DomainMonitorAlertSinkDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'monitor_id': 'str',
        'user_id': 'str',
        'type': 'str',
        'target': 'str',
        'severity_threshold': 'str',
        'enabled': 'bool',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'monitor_id': 'monitorId',
        'user_id': 'userId',
        'type': 'type',
        'target': 'target',
        'severity_threshold': 'severityThreshold',
        'enabled': 'enabled',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, monitor_id=None, user_id=None, type=None, target=None, severity_threshold=None, enabled=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """DomainMonitorAlertSinkDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._monitor_id = None
        self._user_id = None
        self._type = None
        self._target = None
        self._severity_threshold = None
        self._enabled = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.monitor_id = monitor_id
        self.user_id = user_id
        self.type = type
        self.target = target
        self.severity_threshold = severity_threshold
        self.enabled = enabled
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The id of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DomainMonitorAlertSinkDto.


        :param id: The id of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def monitor_id(self):
        """Gets the monitor_id of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The monitor_id of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: str
        """
        return self._monitor_id

    @monitor_id.setter
    def monitor_id(self, monitor_id):
        """Sets the monitor_id of this DomainMonitorAlertSinkDto.


        :param monitor_id: The monitor_id of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and monitor_id is None:  # noqa: E501
            raise ValueError("Invalid value for `monitor_id`, must not be `None`")  # noqa: E501

        self._monitor_id = monitor_id

    @property
    def user_id(self):
        """Gets the user_id of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The user_id of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this DomainMonitorAlertSinkDto.


        :param user_id: The user_id of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def type(self):
        """Gets the type of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The type of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DomainMonitorAlertSinkDto.


        :param type: The type of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["EMAIL", "WEBHOOK", "SLACK", "TEAMS"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def target(self):
        """Gets the target of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The target of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this DomainMonitorAlertSinkDto.


        :param target: The target of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and target is None:  # noqa: E501
            raise ValueError("Invalid value for `target`, must not be `None`")  # noqa: E501

        self._target = target

    @property
    def severity_threshold(self):
        """Gets the severity_threshold of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The severity_threshold of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: str
        """
        return self._severity_threshold

    @severity_threshold.setter
    def severity_threshold(self, severity_threshold):
        """Sets the severity_threshold of this DomainMonitorAlertSinkDto.


        :param severity_threshold: The severity_threshold of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and severity_threshold is None:  # noqa: E501
            raise ValueError("Invalid value for `severity_threshold`, must not be `None`")  # noqa: E501
        allowed_values = ["LOW", "MEDIUM", "HIGH", "CRITICAL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and severity_threshold not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `severity_threshold` ({0}), must be one of {1}"  # noqa: E501
                .format(severity_threshold, allowed_values)
            )

        self._severity_threshold = severity_threshold

    @property
    def enabled(self):
        """Gets the enabled of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The enabled of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this DomainMonitorAlertSinkDto.


        :param enabled: The enabled of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `enabled`, must not be `None`")  # noqa: E501

        self._enabled = enabled

    @property
    def created_at(self):
        """Gets the created_at of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The created_at of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DomainMonitorAlertSinkDto.


        :param created_at: The created_at of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The updated_at of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DomainMonitorAlertSinkDto.


        :param updated_at: The updated_at of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DomainMonitorAlertSinkDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DomainMonitorAlertSinkDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class LookupSpfDomainResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'valid': 'bool',
        'host': 'str',
        'record': 'str',
        'flattened_record': 'str',
        'lookup_count': 'int',
        'mechanisms': 'list[SpfMechanismResult]',
        'warnings': 'list[str]',
        'errors': 'list[str]'
    }

    attribute_map = {
        'valid': 'valid',
        'host': 'host',
        'record': 'record',
        'flattened_record': 'flattenedRecord',
        'lookup_count': 'lookupCount',
        'mechanisms': 'mechanisms',
        'warnings': 'warnings',
        'errors': 'errors'
    }

    def __init__(self, valid=None, host=None, record=None, flattened_record=None, lookup_count=None, mechanisms=None, warnings=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """LookupSpfDomainResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._valid = None
        self._host = None
        self._record = None
        self._flattened_record = None
        self._lookup_count = None
        self._mechanisms = None
        self._warnings = None
        self._errors = None
        self.discriminator = None

        self.valid = valid
        self.host = host
        if record is not None:
            self.record = record
        if flattened_record is not None:
            self.flattened_record = flattened_record
        self.lookup_count = lookup_count
        self.mechanisms = mechanisms
        self.warnings = warnings
        self.errors = errors

    @property
    def valid(self):
        """Gets the valid of this LookupSpfDomainResults.  # noqa: E501


        :return: The valid of this LookupSpfDomainResults.  # noqa: E501
        :rtype: bool
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """Sets the valid of this LookupSpfDomainResults.


        :param valid: The valid of this LookupSpfDomainResults.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and valid is None:  # noqa: E501
            raise ValueError("Invalid value for `valid`, must not be `None`")  # noqa: E501

        self._valid = valid

    @property
    def host(self):
        """Gets the host of this LookupSpfDomainResults.  # noqa: E501


        :return: The host of this LookupSpfDomainResults.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this LookupSpfDomainResults.


        :param host: The host of this LookupSpfDomainResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and host is None:  # noqa: E501
            raise ValueError("Invalid value for `host`, must not be `None`")  # noqa: E501

        self._host = host

    @property
    def record(self):
        """Gets the record of this LookupSpfDomainResults.  # noqa: E501


        :return: The record of this LookupSpfDomainResults.  # noqa: E501
        :rtype: str
        """
        return self._record

    @record.setter
    def record(self, record):
        """Sets the record of this LookupSpfDomainResults.


        :param record: The record of this LookupSpfDomainResults.  # noqa: E501
        :type: str
        """

        self._record = record

    @property
    def flattened_record(self):
        """Gets the flattened_record of this LookupSpfDomainResults.  # noqa: E501


        :return: The flattened_record of this LookupSpfDomainResults.  # noqa: E501
        :rtype: str
        """
        return self._flattened_record

    @flattened_record.setter
    def flattened_record(self, flattened_record):
        """Sets the flattened_record of this LookupSpfDomainResults.


        :param flattened_record: The flattened_record of this LookupSpfDomainResults.  # noqa: E501
        :type: str
        """

        self._flattened_record = flattened_record

    @property
    def lookup_count(self):
        """Gets the lookup_count of this LookupSpfDomainResults.  # noqa: E501


        :return: The lookup_count of this LookupSpfDomainResults.  # noqa: E501
        :rtype: int
        """
        return self._lookup_count

    @lookup_count.setter
    def lookup_count(self, lookup_count):
        """Sets the lookup_count of this LookupSpfDomainResults.


        :param lookup_count: The lookup_count of this LookupSpfDomainResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and lookup_count is None:  # noqa: E501
            raise ValueError("Invalid value for `lookup_count`, must not be `None`")  # noqa: E501

        self._lookup_count = lookup_count

    @property
    def mechanisms(self):
        """Gets the mechanisms of this LookupSpfDomainResults.  # noqa: E501


        :return: The mechanisms of this LookupSpfDomainResults.  # noqa: E501
        :rtype: list[SpfMechanismResult]
        """
        return self._mechanisms

    @mechanisms.setter
    def mechanisms(self, mechanisms):
        """Sets the mechanisms of this LookupSpfDomainResults.


        :param mechanisms: The mechanisms of this LookupSpfDomainResults.  # noqa: E501
        :type: list[SpfMechanismResult]
        """
        if self.local_vars_configuration.client_side_validation and mechanisms is None:  # noqa: E501
            raise ValueError("Invalid value for `mechanisms`, must not be `None`")  # noqa: E501

        self._mechanisms = mechanisms

    @property
    def warnings(self):
        """Gets the warnings of this LookupSpfDomainResults.  # noqa: E501


        :return: The warnings of this LookupSpfDomainResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this LookupSpfDomainResults.


        :param warnings: The warnings of this LookupSpfDomainResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    @property
    def errors(self):
        """Gets the errors of this LookupSpfDomainResults.  # noqa: E501


        :return: The errors of this LookupSpfDomainResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this LookupSpfDomainResults.


        :param errors: The errors of this LookupSpfDomainResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LookupSpfDomainResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LookupSpfDomainResults):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PageInboxProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'content': 'list[InboxPreview]',
        'pageable': 'PageableObject',
        'total_pages': 'int',
        'total_elements': 'int',
        'last': 'bool',
        'size': 'int',
        'number': 'int',
        'first': 'bool',
        'number_of_elements': 'int',
        'sort': 'SortObject',
        'empty': 'bool'
    }

    attribute_map = {
        'content': 'content',
        'pageable': 'pageable',
        'total_pages': 'totalPages',
        'total_elements': 'totalElements',
        'last': 'last',
        'size': 'size',
        'number': 'number',
        'first': 'first',
        'number_of_elements': 'numberOfElements',
        'sort': 'sort',
        'empty': 'empty'
    }

    def __init__(self, content=None, pageable=None, total_pages=None, total_elements=None, last=None, size=None, number=None, first=None, number_of_elements=None, sort=None, empty=None, local_vars_configuration=None):  # noqa: E501
        """PageInboxProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._content = None
        self._pageable = None
        self._total_pages = None
        self._total_elements = None
        self._last = None
        self._size = None
        self._number = None
        self._first = None
        self._number_of_elements = None
        self._sort = None
        self._empty = None
        self.discriminator = None

        if content is not None:
            self.content = content
        if pageable is not None:
            self.pageable = pageable
        self.total_pages = total_pages
        self.total_elements = total_elements
        if last is not None:
            self.last = last
        if size is not None:
            self.size = size
        if number is not None:
            self.number = number
        if first is not None:
            self.first = first
        if number_of_elements is not None:
            self.number_of_elements = number_of_elements
        if sort is not None:
            self.sort = sort
        if empty is not None:
            self.empty = empty

    @property
    def content(self):
        """Gets the content of this PageInboxProjection.  # noqa: E501


        :return: The content of this PageInboxProjection.  # noqa: E501
        :rtype: list[InboxPreview]
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this PageInboxProjection.


        :param content: The content of this PageInboxProjection.  # noqa: E501
        :type: list[InboxPreview]
        """

        self._content = content

    @property
    def pageable(self):
        """Gets the pageable of this PageInboxProjection.  # noqa: E501


        :return: The pageable of this PageInboxProjection.  # noqa: E501
        :rtype: PageableObject
        """
        return self._pageable

    @pageable.setter
    def pageable(self, pageable):
        """Sets the pageable of this PageInboxProjection.


        :param pageable: The pageable of this PageInboxProjection.  # noqa: E501
        :type: PageableObject
        """

        self._pageable = pageable

    @property
    def total_pages(self):
        """Gets the total_pages of this PageInboxProjection.  # noqa: E501


        :return: The total_pages of this PageInboxProjection.  # noqa: E501
        :rtype: int
        """
        return self._total_pages

    @total_pages.setter
    def total_pages(self, total_pages):
        """Sets the total_pages of this PageInboxProjection.


        :param total_pages: The total_pages of this PageInboxProjection.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_pages is None:  # noqa: E501
            raise ValueError("Invalid value for `total_pages`, must not be `None`")  # noqa: E501

        self._total_pages = total_pages

    @property
    def total_elements(self):
        """Gets the total_elements of this PageInboxProjection.  # noqa: E501


        :return: The total_elements of this PageInboxProjection.  # noqa: E501
        :rtype: int
        """
        return self._total_elements

    @total_elements.setter
    def total_elements(self, total_elements):
        """Sets the total_elements of this PageInboxProjection.


        :param total_elements: The total_elements of this PageInboxProjection.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_elements is None:  # noqa: E501
            raise ValueError("Invalid value for `total_elements`, must not be `None`")  # noqa: E501

        self._total_elements = total_elements

    @property
    def last(self):
        """Gets the last of this PageInboxProjection.  # noqa: E501


        :return: The last of this PageInboxProjection.  # noqa: E501
        :rtype: bool
        """
        return self._last

    @last.setter
    def last(self, last):
        """Sets the last of this PageInboxProjection.


        :param last: The last of this PageInboxProjection.  # noqa: E501
        :type: bool
        """

        self._last = last

    @property
    def size(self):
        """Gets the size of this PageInboxProjection.  # noqa: E501


        :return: The size of this PageInboxProjection.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this PageInboxProjection.


        :param size: The size of this PageInboxProjection.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def number(self):
        """Gets the number of this PageInboxProjection.  # noqa: E501


        :return: The number of this PageInboxProjection.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this PageInboxProjection.


        :param number: The number of this PageInboxProjection.  # noqa: E501
        :type: int
        """

        self._number = number

    @property
    def first(self):
        """Gets the first of this PageInboxProjection.  # noqa: E501


        :return: The first of this PageInboxProjection.  # noqa: E501
        :rtype: bool
        """
        return self._first

    @first.setter
    def first(self, first):
        """Sets the first of this PageInboxProjection.


        :param first: The first of this PageInboxProjection.  # noqa: E501
        :type: bool
        """

        self._first = first

    @property
    def number_of_elements(self):
        """Gets the number_of_elements of this PageInboxProjection.  # noqa: E501


        :return: The number_of_elements of this PageInboxProjection.  # noqa: E501
        :rtype: int
        """
        return self._number_of_elements

    @number_of_elements.setter
    def number_of_elements(self, number_of_elements):
        """Sets the number_of_elements of this PageInboxProjection.


        :param number_of_elements: The number_of_elements of this PageInboxProjection.  # noqa: E501
        :type: int
        """

        self._number_of_elements = number_of_elements

    @property
    def sort(self):
        """Gets the sort of this PageInboxProjection.  # noqa: E501


        :return: The sort of this PageInboxProjection.  # noqa: E501
        :rtype: SortObject
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this PageInboxProjection.


        :param sort: The sort of this PageInboxProjection.  # noqa: E501
        :type: SortObject
        """

        self._sort = sort

    @property
    def empty(self):
        """Gets the empty of this PageInboxProjection.  # noqa: E501


        :return: The empty of this PageInboxProjection.  # noqa: E501
        :rtype: bool
        """
        return self._empty

    @empty.setter
    def empty(self, empty):
        """Sets the empty of this PageInboxProjection.


        :param empty: The empty of this PageInboxProjection.  # noqa: E501
        :type: bool
        """

        self._empty = empty

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PageInboxProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PageInboxProjection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.deliverability_test_controller_api import DeliverabilityTestControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestDeliverabilityTestControllerApi(unittest.TestCase):
    """DeliverabilityTestControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.deliverability_test_controller_api.DeliverabilityTestControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_deliverability_simulation_job(self):
        """Test case for cancel_deliverability_simulation_job

        Cancel deliverability simulation job  # noqa: E501
        """
        pass

    def test_create_deliverability_simulation_job(self):
        """Test case for create_deliverability_simulation_job

        Create deliverability simulation job  # noqa: E501
        """
        pass

    def test_create_deliverability_test(self):
        """Test case for create_deliverability_test

        Create deliverability/load test  # noqa: E501
        """
        pass

    def test_delete_deliverability_test(self):
        """Test case for delete_deliverability_test

        Delete deliverability/load test  # noqa: E501
        """
        pass

    def test_duplicate_deliverability_test(self):
        """Test case for duplicate_deliverability_test

        Duplicate deliverability/load test  # noqa: E501
        """
        pass

    def test_export_deliverability_test_report(self):
        """Test case for export_deliverability_test_report

        Export deliverability/load test report as PDF  # noqa: E501
        """
        pass

    def test_export_deliverability_test_results(self):
        """Test case for export_deliverability_test_results

        Export deliverability/load test entity results as CSV  # noqa: E501
        """
        pass

    def test_get_deliverability_analytics_series(self):
        """Test case for get_deliverability_analytics_series

        Get deliverability analytics time series  # noqa: E501
        """
        pass

    def test_get_deliverability_failure_hotspots(self):
        """Test case for get_deliverability_failure_hotspots

        Get deliverability failure hotspots  # noqa: E501
        """
        pass

    def test_get_deliverability_simulation_job(self):
        """Test case for get_deliverability_simulation_job

        Get deliverability simulation job  # noqa: E501
        """
        pass

    def test_get_deliverability_simulation_job_events(self):
        """Test case for get_deliverability_simulation_job_events

        Get deliverability simulation job events  # noqa: E501
        """
        pass

    def test_get_deliverability_test(self):
        """Test case for get_deliverability_test

        Get deliverability/load test  # noqa: E501
        """
        pass

    def test_get_deliverability_test_results(self):
        """Test case for get_deliverability_test_results

        Get deliverability/load test entity results  # noqa: E501
        """
        pass

    def test_get_deliverability_tests(self):
        """Test case for get_deliverability_tests

        List deliverability/load tests  # noqa: E501
        """
        pass

    def test_get_latest_deliverability_simulation_job(self):
        """Test case for get_latest_deliverability_simulation_job

        Get latest deliverability simulation job  # noqa: E501
        """
        pass

    def test_pause_deliverability_simulation_job(self):
        """Test case for pause_deliverability_simulation_job

        Pause deliverability simulation job  # noqa: E501
        """
        pass

    def test_pause_deliverability_test(self):
        """Test case for pause_deliverability_test

        Pause deliverability/load test  # noqa: E501
        """
        pass

    def test_poll_deliverability_test_status(self):
        """Test case for poll_deliverability_test_status

        Poll deliverability/load test status  # noqa: E501
        """
        pass

    def test_resume_deliverability_simulation_job(self):
        """Test case for resume_deliverability_simulation_job

        Resume deliverability simulation job  # noqa: E501
        """
        pass

    def test_start_deliverability_test(self):
        """Test case for start_deliverability_test

        Start or resume deliverability/load test  # noqa: E501
        """
        pass

    def test_stop_deliverability_test(self):
        """Test case for stop_deliverability_test

        Stop deliverability/load test  # noqa: E501
        """
        pass

    def test_update_deliverability_test(self):
        """Test case for update_deliverability_test

        Update deliverability/load test  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
